==> frezka_admin_panel_updated_files_v3.0.0.zip: lang/el/booking.php <==
<?php

return [
    'title' => 'Κρατήσεις',
    'singular_title' => 'Κράτηση',
    'lbl_phone' => 'Τηλέφωνο:',
    'lbl_e-mail' => 'Ηλεκτρονικό ταχυδρομείο:',
    'lbl_with' => 'Με',
    'lbl_at' => 'Στις:',
    'lbl_note' => 'Σημείωση',
    'lbl_sub_tot' => 'Υποσύνολο:',
    'lbl_got_to_payment' => 'Μετάβαση στην πληρωμή',
    'lbl_complete_now' => 'Ολοκλήρωση τώρα',
    'lbl_payment' => 'Πληρωμή',
    'lbl_pay_now' => 'Πλήρωσε τώρα',
    'lbl_is_paid' => 'Πληρώθηκε',
    'lbl_add_service' => 'Προσθήκη Υπηρεσίας',
    'lbl_add_package' => 'Προσθήκη Πακέτου',
    'lbl_date' => 'Ημερομηνία',
    'lbl_customer_name' => 'Όνομα πελάτη',
    'lbl_amount' => 'Ποσό',
    'lbl_duration' => 'Διάρκεια',
    'lbl_staff_name' => 'Όνομα προσωπικού',
    'lbl_services' => 'Υπηρεσίες',
    'lbl_update_at' => 'Ενημερώθηκε στις',
    'lbl_status' => 'Κατάσταση',
    'booking_update' => 'Ενημερώθηκε κράτηση',
    'booking_status_list' => 'Λίστα κατάστασης κράτησης',
    'search_booking' => 'Αποτελέσματα αναζήτησης για κρατήσεις.',
    'booking_detail' => 'Λεπτομέρειες κράτησης',
    'booking_list' => 'Λίστα κρατήσεων',
    'status_update' => 'Η κατάσταση ενημερώθηκε!',
    'booking_delete' => 'Διαγράφηκε με επιτυχία',
    'booking_not_found' => 'Δεν βρέθηκε κράτηση',
    'payment_done' => 'Επιτυχής πληρωμή',
    'booking_branch' => 'ΛΙΣΤΑ_ΚΛΑΔΙΟΥ',
    'booking_timeslot' => 'ΛΙΣΤΑ_ΧΡΟΝΟΥ_ΥΠΟΔΕΙΞΗΣ',
    'booking_category' => 'ΛΙΣΤΑ_ΚΑΤΗΓΟΡΙΑΣ',
    'booking_sevice' => 'ΛΙΣΤΑ_ΥΠΗΡΕΣΙΩΝ',
    'booking_employee' => 'ΛΙΣΤΑ_ΥΠΑΛΛΗΛΩΝ',
    'booking_create' => 'ΔΗΜΙΟΥΡΓΗΘΗΚΕ_ΚΡΑΤΗΣΗ',
    'booking_action_invalid' => 'Μη έγκυρη ενέργεια',
    'booking_service_update' => 'Ενημέρωση υπηρεσίας κράτησης με επιτυχία',
    'payment_successfull' => 'Επιτυχής πληρωμή',
    'create_form' => 'Το :form δημιουργήθηκε με επιτυχία',
    'lbl_action' => 'Δράση',
    'lbl_new_appointment' => 'Νέος διορισμός',
    'lbl_appointment' => 'Ραντεβού',
    'lbl_advanced_filter' => 'Προηγμένο φίλτρο',
    'lbl_booking_date' => 'Ημερομηνία κράτησης',
    'lbl_customer_name' => 'Όνομα πελάτη',
    'lbl_staff_name' => 'Όνομα προσωπικού',
    'lbl_services' => 'Υπηρεσίες',
    'lbl_payment_status' => 'Κατάσταση πληρωμής',
    'download_invoice' => 'Λήψη τιμολογίου',
    'name' => 'όνομα',
    'phone' => 'τηλέφωνο',
    'email' => 'Ηλεκτρονικό ταχυδρομείο',
    'payment_method' => 'Τρόπος πληρωμής',
    'customer_info' => 'Πληροφορίες πελάτη',
    'services' => 'Υπηρεσίες ',
    'unit_price' => 'Τιμή μονάδας',
    'qty' => 'Ποσότητα',
    'total_price' => 'Συνολική τιμή',
    'tips' => 'Συμβουλές',
    'tax' => 'Φόρος',
    'grand-total' => 'Γενικό σύνολο',
    'sub_total' => 'Μερικό σύνολο',
    'products' => 'Προϊόντα',
    'invoice_data' => 'Στοιχεία τιμολογίου',
    'coupondiscount' => 'Έκπτωση Κουπονιού',
    'grand_total' => 'Σύνολο',
    'tips' => 'Φιλοδωρήματα',
    'billing_address' => 'Διεύθυνση Χρέωσης'

];

==> frezka_admin_panel_updated_files_v3.3.0.zip: lang/el/booking.php <==
<?php

return [
    'title' => 'Κρατήσεις',
    'singular_title' => 'Κράτηση',
    'lbl_phone' => 'Τηλέφωνο:',
    'lbl_e-mail' => 'Ηλεκτρονικό ταχυδρομείο:',
    'lbl_with' => 'Με',
    'lbl_at' => 'Στις:',
    'lbl_note' => 'Σημείωση',
    'lbl_sub_tot' => 'Υποσύνολο:',
    'lbl_got_to_payment' => 'Μετάβαση στην πληρωμή',
    'lbl_complete_now' => 'Ολοκλήρωση τώρα',
    'lbl_payment' => 'Πληρωμή',
    'lbl_pay_now' => 'Πλήρωσε τώρα',
    'lbl_is_paid' => 'Πληρώθηκε',
    'lbl_add_service' => 'Προσθήκη Υπηρεσίας',
    'lbl_add_package' => 'Προσθήκη Πακέτου',
    'lbl_date' => 'Ημερομηνία',
    'lbl_customer_name' => 'Πελάτης',
    'lbl_amount' => 'Ποσό',
    'lbl_duration' => 'Διάρκεια',
    'lbl_staff_name' => 'Προσωπικό',
    'lbl_services' => 'Υπηρεσίες',
    'lbl_update_at' => 'Ενημερώθηκε στις',
    'lbl_status' => 'Κατάσταση',
    'booking_update' => 'Ενημερώθηκε κράτηση',
    'booking_status_list' => 'Λίστα κατάστασης κράτησης',
    'search_booking' => 'Αποτελέσματα αναζήτησης για κρατήσεις.',
    'booking_detail' => 'Λεπτομέρειες κράτησης',
    'booking_list' => 'Λίστα κρατήσεων',
    'status_update' => 'Η κατάσταση ενημερώθηκε!',
    'booking_delete' => 'Διαγράφηκε με επιτυχία',
    'booking_not_found' => 'Δεν βρέθηκε κράτηση',
    'payment_done' => 'Επιτυχής πληρωμή',
    'booking_branch' => 'ΛΙΣΤΑ_ΚΛΑΔΙΟΥ',
    'booking_timeslot' => 'ΛΙΣΤΑ_ΧΡΟΝΟΥ_ΥΠΟΔΕΙΞΗΣ',
    'booking_category' => 'ΛΙΣΤΑ_ΚΑΤΗΓΟΡΙΑΣ',
    'booking_sevice' => 'ΛΙΣΤΑ_ΥΠΗΡΕΣΙΩΝ',
    'booking_employee' => 'ΛΙΣΤΑ_ΥΠΑΛΛΗΛΩΝ',
    'booking_create' => 'ΔΗΜΙΟΥΡΓΗΘΗΚΕ_ΚΡΑΤΗΣΗ',
    'booking_action_invalid' => 'Μη έγκυρη ενέργεια',
    'booking_service_update' => 'Ενημέρωση υπηρεσίας κράτησης με επιτυχία',
    'payment_successfull' => 'Επιτυχής πληρωμή',
    'create_form' => 'Το :form δημιουργήθηκε με επιτυχία',
    'lbl_action' => 'Δράση',
    'lbl_new_appointment' => 'Νέος διορισμός',
    'lbl_appointment' => 'Ραντεβού',
    'lbl_advanced_filter' => 'Προηγμένο φίλτρο',
    'lbl_booking_date' => 'Ημερομηνία κράτησης',
    'lbl_customer_name' => 'Όνομα πελάτη',
    'lbl_staff_name' => 'Όνομα προσωπικού',
    'lbl_services' => 'Υπηρεσίες',
    'lbl_payment_status' => 'Κατάσταση πληρωμής',
    'download_invoice' => 'τιμολογίου',
    'name' => 'όνομα',
    'phone' => 'τηλέφωνο',
    'email' => 'Ηλεκτρονικό ταχυδρομείο',
    'payment_method' => 'Τρόπος πληρωμής',
    'customer_info' => 'Πληροφορίες πελάτη',
    'services' => 'Υπηρεσίες ',
    'unit_price' => 'Τιμή μονάδας',
    'qty' => 'Ποσότητα',
    'total_price' => 'Συνολική τιμή',
    'tips' => 'Συμβουλές',
    'tax' => 'Φόρος',
    'grand-total' => 'Γενικό σύνολο',
    'sub_total' => 'Μερικό σύνολο',
    'products' => 'Προϊόντα',
    'invoice_data' => 'Στοιχεία τιμολογίου',
    'coupondiscount' => 'Έκπτωση Κουπονιού',
    'grand_total' => 'Σύνολο',
    'tips' => 'Φιλοδωρήματα',
    'billing_address' => 'Διεύθυνση Χρέωσης',
    'grand_total' => 'Συνολικό ποσό:',
    'lbl_packages' => 'Πακέτα',
    'lbl_add_more' => 'Προσθέστε περισσότερα',
    'lbl_packages_detail' => 'Λεπτομέρειες πακέτων',
    'lbl_package_available' => 'Διαθέσιμα πακέτα',
    'lbl_package_active' => 'Το πακέτο σας είναι ακόμα ενεργό',
    'lbl_view_all' => 'Προβολή όλων',
    'booking_date' => 'Επιλέξτε ημερομηνία κράτησης',
    'customer_name' => 'Επιλέξτε όνομα πελάτη',
    'staff_name' => 'Επιλέξτε όνομα προσωπικού',
    'select_service' => 'Επιλέξτε υπηρεσίες',
    'branch_name' => 'Όνομα Υποκαταστήματος',
    'invoice_time' => 'Χρόνος Τιμολόγησης',
    'payment_type' => 'Τύπος πληρωμής',
    'service_amount' => 'Ποσό υπηρεσίας',
    'product_amount' => 'Ποσό προϊόντος',
    'package_amount' => 'Ποσό πακέτου',
    'tip_amount' => 'Τιπ',
    'total' => 'Σύνολο',
    'final_total' => 'Τελικό σύνολο',
    'booking_detail' => 'Λεπτομέρειες κράτησης',
    'booked_on' => 'Κρατημένο στις',
    'booked_by' => 'Κρατημένο από',
    'updated_on' => 'Ενημερώθηκε στις',
    'updated_by' => 'Ενημερώθηκε από',
    'sale' => 'Πώληση #0',
    'with' => 'Με',
    'sold_by' => 'Πωληθέν από',
    'client_since' => 'Πελάτης από',
    'coupon_discount' => 'Έκπτωση κουπονιού',

];
